"""Assets module"""

WELCOME_MESSAGE = """
Welcome to Sai. Chat with your local LLM models.
"""

HELP_MESSAGE = """
### Available commands:
- `/setup` : Setup Ollama URL
- `/model` : Select a model
- `/help` : Show this help message
- `/quit` : Exit the application
"""

DEFAULT_PROMPT: str = "You are a virtual assistant. Reply shortly and concise, in a fun tone."
